import sys

def is_homozygous(genotype):
    alleles = genotype.split('/')
    return alleles[0] == alleles[1]

def process_vcf(file_path):
    with open(file_path, 'r') as file:
        for line in file:
            # Skip header lines
            if line.startswith('#'):
                continue

            # Split line into columns
            columns = line.strip().split('\t')

            # Extract genotype information
            maternal_genotype = columns[9].split(':')[0]
            paternal_genotype = columns[10].split(':')[0]

            # Check for missing genotypes
            if './.' in [maternal_genotype, paternal_genotype]:
                continue

            # Check if both genotypes are homozygous and not identical
            if is_homozygous(maternal_genotype) and is_homozygous(paternal_genotype) and maternal_genotype != paternal_genotype:
                print(line.strip())

if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Usage: python script.py <VCF_FILE>")
        sys.exit(1)

    vcf_file_path = sys.argv[1]
    process_vcf(vcf_file_path)

